@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from typing import Union
+from typing import Union, Type
 
 from fastapi import Depends, HTTPException
 from jose import JWTError
@@ -88,7 +88,7 @@ def CurrentUserId(*, optional: bool = False, token_name: str = 'access_token'):
 if is_tortoise_installed:
     from tortoise.exceptions import DoesNotExist
 
-    def current_user(model: BaseModel = None, *, optional: bool = False, token_name: str = 'access_token'):
+    def current_user(model: Type[BaseModel] = None, *, optional: bool = False, token_name: str = 'access_token'):
 
         async def _get(cuid: Union[int, None] = CurrentUserId(token_name=token_name, optional=optional)):
             nonlocal model
@@ -104,7 +104,7 @@ if is_tortoise_installed:
                     raise credentials_exception
 
             try:
-                return await model.get(user_id=cuid)
+                return await model.get(pk=cuid)
             except DoesNotExist:
                 if optional:
                     return None
@@ -118,5 +118,5 @@ else:
         raise RuntimeError('no supported ORM installed')
 
 
-def CurrentUser(*, optional: bool = False, token_name: str = 'access_token', model: BaseModel = None):
+def CurrentUser(*, optional: bool = False, token_name: str = 'access_token', model: Type[BaseModel] = None):
     return Depends(current_user(model, optional=optional, token_name=token_name))
